library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
--use ieee.std_logic_arith.all;

entity TRACKER is
  port ( iClk_27 	: in std_logic;
	 iRST_N	 	: in std_logic;

	 -- ITU 656 Decoder output
	 iRed	 	: in std_logic_vector(9 downto 0);
         iGreen		: in std_logic_vector(9 downto 0);
	 iBlue		: in std_logic_vector(9 downto 0);

	 -- Inputs for testing
	 iSwitch	: in std_logic_vector (17 downto 0);

	 -- Coordinate input
	 iCoordinate_x	: in std_logic_vector(9 downto 0);
	 iCoordinate_y	: in std_logic_vector(9 downto 0);
	 
	 -- For testing
	 oGreenLED	: out std_logic_vector(7 downto 0);	

	 -- Output
	 oTracked_x	: out std_logic_vector(9 downto 0);
	 oTracked_y	: out std_logic_vector(9 downto 0)
	 );
end TRACKER;

architecture rtl of TRACKER is

signal unsign	 : unsigned(17 downto 0);
signal x_address : std_logic_vector(9 downto 0);
signal y_address : std_logic_vector(9 downto 0);
signal saved_x	 : std_logic_vector(9 downto 0);
signal saved_y	 : std_logic_vector(9 downto 0);

begin  --  rtl 

    detection : process (iClk_27)

    variable counter	 : unsigned(9 downto 0) := "0000000000";
    variable saved_counter : unsigned(9 downto 0) := "0000000000";
    variable field	 : std_logic := '0';

    begin
		
	if (iClk_27'event and iClk_27 = '1') then

	    unsign <= unsigned(iSwitch);

	    oGreenLED(0) <= counter(0);

    	    if ( iRed(9 downto 7) = std_logic_vector(unsign(17 downto 15))
		    and iGreen(9 downto 7) = std_logic_vector(unsign(14 downto 12))
		    and iBlue(9 downto 7) = std_logic_vector(unsign(11 downto 10)) ) then
	    	counter := counter + 1;
	    	
	    else

	    	if (counter > unsign(9 downto 0) and counter > saved_counter) then
		    --green_led_buff(1) := green_led_buff(1) xor 1;
		    saved_x <= std_logic_vector(unsigned(iCoordinate_x) + (counter srl 1));
	     	    saved_y <= iCoordinate_y;
		    saved_counter := counter;
	    	end if;

	        counter := "0000000000";

	    end if;

	    -- New line
	    if (iCoordinate_x = "0000000000") then
		counter := "0000000000";
	    end if;

	    -- New field
	    if (iCoordinate_y = "0000000000") then
		if (field = '1') then
		    oTracked_y <= saved_x;
		    oTracked_x <= saved_y;
		end if;
		
		field := field xor '1';

		saved_counter := "0000000000";
	    end if;

	end if;

    end process;


end rtl;
